@@ -1,8 +1,6 @@
-"""
-This Source Code Form is subject to the terms of the Mozilla Public
-License, v. 2.0. If a copy of the MPL was not distributed with this
-file, You can obtain one at http://mozilla.org/MPL/2.0/.
-"""
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 TEST_RUNNER = 'django_nose.runner.NoseTestSuiteRunner'
 
 SECRET_KEY = 'asdf'
@@ -21,6 +19,7 @@ INSTALLED_APPS = (
 
     'django.contrib.auth',
     'django.contrib.contenttypes',
+    'django.contrib.staticfiles',
 )
 
 ROOT_URLCONF = 'django_browserid.tests.urls'
@@ -29,7 +28,7 @@ AUTHENTICATION_BACKENDS = (
     'django_browserid.auth.BrowserIDBackend',
 )
 
-SITE_URL = 'http://testserver'
-
 BROWSERID_CREATE_USER = True
 BROWSERID_USERNAME_ALGO = None
+
+STATIC_URL = 'static/'
