@@ -1,15 +1,13 @@
-"""
-This Source Code Form is subject to the terms of the Mozilla Public
-License, v. 2.0. If a copy of the MPL was not distributed with this
-file, You can obtain one at http://mozilla.org/MPL/2.0/.
-"""
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.test import TestCase
 
 from mock import ANY, patch
 
-from django_browserid.auth import BrowserIDBackend, default_username_algo
+from django_browserid.auth import BrowserIDBackend, default_username_algo, verify
 from django_browserid.tests import mock_browserid
 
 # Support Python 2.6 by using unittest2
@@ -33,7 +31,7 @@ def new_user(email, username=None):
 
 
 class BrowserIDBackendTests(TestCase):
-    def auth(self, verified_email=None):
+    def auth(self, verified_email=None, browserid_extra=None):
         """
         Attempt to authenticate a user with BrowserIDBackend.
 
@@ -42,7 +40,7 @@ class BrowserIDBackendTests(TestCase):
         """
         with mock_browserid(verified_email):
             backend = BrowserIDBackend()
-            return backend.authenticate(assertion='asdf', audience='asdf')
+            return backend.authenticate(assertion='asdf', audience='asdf', browserid_extra=browserid_extra)
 
     def test_failed_verification(self):
         # If verification fails, return None.
@@ -100,6 +98,12 @@ class BrowserIDBackendTests(TestCase):
         user = self.auth('a@b.com')
         user_created.send.assert_called_with(ANY, user=user)
 
+    @patch('django_browserid.auth.verify', wraps=verify)
+    def test_verify_called_with_browserid_extra(self, user_verify):
+        dic = {'a': 'AlphaA'}
+        self.auth('a@b.com', browserid_extra=dic)
+        user_verify.assert_called_with('asdf', 'asdf', extra_params=dic)
+
 
 # Only run custom user model tests if we're using a version of Django that
 # supports it.
