@@ -1,8 +1,6 @@
-"""
-This Source Code Form is subject to the terms of the Mozilla Public
-License, v. 2.0. If a copy of the MPL was not distributed with this
-file, You can obtain one at http://mozilla.org/MPL/2.0/.
-"""
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from contextlib import contextmanager
 
 from django.conf import settings
@@ -49,7 +47,7 @@ def test_backend_verify(fake):
     # Test that authenticate() calls verify().
     fake.return_value = False
     auth.authenticate(**authenticate_kwargs)
-    fake.assert_called_with(assertion, audience)
+    fake.assert_called_with(assertion, audience, extra_params=None)
 
 
 @mock_browserid(None)
@@ -134,3 +132,39 @@ def test_verify_post_uses_custom_settings(post):
                             data=ANY,
                             timeout=1,
                             headers=ANY)
+
+
+@patch('django_browserid.base.requests.post')
+def test_verify_with_custom_url(post):
+    post.return_value.content = '{"status": "okay"}'
+    url = 'https://custom-service.org/verify'
+    verify(assertion, audience, url=url)
+    post.assert_called_with(url,
+                            verify=ANY,
+                            proxies=ANY,
+                            data=ANY,
+                            timeout=ANY,
+                            headers=ANY)
+
+
+@patch.object(settings, 'BROWSERID_ALLOW_UNVERIFIED', True, create=True)
+@patch.object(settings, 'BROWSERID_VERIFICATION_URL', 'https://unverifier.persona.org/verify', create=True)
+@mock_browserid(pass_mock=True)
+def test_authenticate_unverified_user(_verify_http_request):
+    """
+    Test that extra parameters are passed through to _verify_http_request
+    correctly.
+    """
+    # In real life, BROWSERID_VERIFICATION_URL would point to the
+    # BID Unverified Email verifier. (Yes, that makes my head hurt too.)
+    args = dict(authenticate_kwargs)
+    args['extra_params'] = {
+        'issuer': 'a.b.c',
+        'allow_unverified': True,
+        'first_name': u'P\xe3ter'
+    }
+
+    verify(**args)
+    _verify_http_request.assert_called_once_with(
+        'https://unverifier.persona.org/verify', ANY)
+    assert _verify_http_request.call_args[0][1]['allow_unverified']
