@@ -1,25 +1,22 @@
-"""
-This Source Code Form is subject to the terms of the Mozilla Public
-License, v. 2.0. If a copy of the MPL was not distributed with this
-file, You can obtain one at http://mozilla.org/MPL/2.0/.
-"""
-from django.conf import settings
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from django.contrib import auth
 from django.test.client import RequestFactory
 
 from mock import patch
 
-from django_browserid import views
-from django_browserid.tests import mock_browserid
+from django_browserid import BrowserIDException, views
+from django_browserid.tests import mock_browserid, patch_settings
 
 
 factory = RequestFactory()
 
 
-def verify(request_type, redirect_field_name=None, success_url=None,
-           failure_url=None, **kwargs):
-    """Call the verify view function. All kwargs not specified above will be
-    passed as GET or POST arguments.
+def verify(request_type, success_url=None, failure_url=None, **kwargs):
+    """
+    Call the verify view function. All kwargs not specified above will be passed
+    as GET or POST arguments.
     """
     if request_type == 'get':
         request = factory.get('/browserid/verify', kwargs)
@@ -27,33 +24,18 @@ def verify(request_type, redirect_field_name=None, success_url=None,
         request = factory.post('/browserid/verify', kwargs)
 
     # Patch settings prior to importing verify
-    patches = []
+    patches = {'BROWSERID_CREATE_USER': True, 'SITE_URL': 'http://testserver'}
     if success_url is not None:
-        patches.append(patch.object(settings, 'LOGIN_REDIRECT_URL',
-                                    success_url, create=True))
+        patches['LOGIN_REDIRECT_URL'] = success_url
     if failure_url is not None:
-        patches.append(patch.object(settings, 'LOGIN_REDIRECT_URL_FAILURE',
-                                    failure_url, create=True))
-    # Create users if they don't exist for testing.
-    patches.append(patch.object(settings, 'BROWSERID_CREATE_USER', True,
-                                create=True))
-
-    # Only pass redirect_field_name if it is specified
-    verify_kwargs = {}
-    if redirect_field_name is not None:
-        verify_kwargs['redirect_field_name'] = redirect_field_name
-
-    for p in patches:
-        p.start()
+        patches['LOGIN_REDIRECT_URL_FAILURE'] = failure_url
 
     # We need to reload verify for the setting changes to take effect.
-    reload(views)
-    verify_view = views.Verify.as_view()
-    with patch.object(auth, 'login'):
-        response = verify_view(request, **verify_kwargs)
-
-    for p in patches:
-        p.stop()
+    with patch_settings(**patches):
+        reload(views)
+        verify_view = views.Verify.as_view()
+        with patch.object(auth, 'login'):
+            response = verify_view(request)
 
     return response
 
@@ -83,6 +65,9 @@ def test_auth_fail_redirect_failure():
 @mock_browserid(None)
 def test_auth_fail_url_parameters():
     # Ensure that bid_login_failed=1 is appended to the failure url.
+    response = verify('post', failure_url='/fail', assertion='asdf')
+    assert response['Location'].endswith('/fail?bid_login_failed=1')
+
     response = verify('post', failure_url='/fail?', assertion='asdf')
     assert response['Location'].endswith('/fail?bid_login_failed=1')
 
@@ -98,6 +83,18 @@ def test_auth_fail_url_parameters():
                                          '&bid_login_failed=1')
 
 
+@mock_browserid(None)
+@patch('django_browserid.views.auth.authenticate')
+def test_authenticate_browserid_exception(authenticate):
+    # If authenticate raises a BrowserIDException, redirect to the failure URL.
+    err = BrowserIDException('test')
+    authenticate.side_effect = err
+
+    response = verify('post', failure_url='/fail', assertion='asdf')
+    assert response.status_code == 302
+    assert response['Location'].endswith('/fail?bid_login_failed=1')
+
+
 @mock_browserid('test@example.com')
 def test_auth_success_redirect_success():
     # If authentication succeeds, redirect to the success URL.
@@ -107,21 +104,67 @@ def test_auth_success_redirect_success():
 
 
 @mock_browserid('test@example.com')
-def test_default_redirect_field():
+def test_redirect_field():
     # If a redirect is passed as an argument to the request, redirect to that
     # instead of the success URL.
-    kwargs = {auth.REDIRECT_FIELD_NAME: '/field_success', 'assertion': 'asdf'}
+    kwargs = {'next': '/field_success', 'assertion': 'asdf'}
     response = verify('post', success_url='/success', **kwargs)
     assert response.status_code == 302
     assert response['Location'].endswith('/field_success')
 
 
 @mock_browserid('test@example.com')
-def test_redirect_field_name():
-    # If a redirect field name is specified, use the request argument matching
-    # that name as the path to redirect to.
-    kwargs = {'my_redirect': '/field_success', 'assertion': 'asdf'}
-    response = verify('post', success_url='/success',
-                      redirect_field_name='my_redirect', **kwargs)
+def test_redirect_invalid_host():
+    # If the given redirect url points to an invalid host, redirect to the
+    # default failure URL.
+    response = verify('post', next='http://example.com/login_failure',
+                      success_url='/woo', assertion='asdf')
     assert response.status_code == 302
-    assert response['Location'].endswith('/field_success')
+    assert response['Location'].endswith('/woo')
+
+
+@patch_settings(DEBUG=True, SESSION_COOKIE_SECURE=True)
+@patch('django_browserid.views.logger.debug')
+def test_sanity_session_cookie(debug):
+    # If DEBUG == True and SESSION_COOKIE_SECURE == True, log a debug message
+    # warning about it.
+    verify('post', assertion='asdf')
+    debug.called = True
+
+
+@patch_settings(DEBUG=True, MIDDLEWARE_CLASSES=['csp.middleware.CSPMiddleware'])
+@patch('django_browserid.views.logger.debug')
+def test_sanity_csp(debug):
+    # If DEBUG == True, the django-csp middleware is present, and Persona isn't
+    # allowed by CSP, log a debug message warning about it.
+
+    # Test if allowed properly.
+    with patch_settings(CSP_DEFAULT_SRC=[],
+                        CSP_SCRIPT_SRC=['https://login.persona.org'],
+                        CSP_FRAME_SRC=['https://login.persona.org']):
+        verify('post', assertion='asdf')
+        debug.called = False
+    debug.reset_mock()
+
+    # Test fallback to default-src.
+    with patch_settings(CSP_DEFAULT_SRC=['https://login.persona.org'],
+                        CSP_SCRIPT_SRC=[],
+                        CSP_FRAME_SRC=[]):
+        verify('post', assertion='asdf')
+        debug.called = False
+    debug.reset_mock()
+
+    # Test incorrect csp.
+    with patch_settings(CSP_DEFAULT_SRC=[],
+                        CSP_SCRIPT_SRC=[],
+                        CSP_FRAME_SRC=[]):
+        verify('post', assertion='asdf')
+        debug.called = True
+    debug.reset_mock()
+
+    # Test partial incorrectness.
+    with patch_settings(CSP_DEFAULT_SRC=[],
+                        CSP_SCRIPT_SRC=['https://login.persona.org'],
+                        CSP_FRAME_SRC=[]):
+        verify('post', assertion='asdf')
+        debug.called = True
